@@ -25,7 +25,7 @@ class Distance(WBits):
 
         command = 'distance{}.get_distance()'.format(self.index)
         value = self._get_command(command)
-        return eval(value)
+        return self.val_process(value)
         
 
     
